__title__ = 'DRF Composable Permissions'
__version__ = '0.1.1'
__author__ = 'Jeffrey de Lange'
__license__ = 'BSD 2-Clause'
__copyright__ = 'Copyright 2016 Jeffrey de Lange'

# Version synonym
VERSION = __version__
